#from distutils.core import setup
from setuptools import setup

setup(
	name='TICC',
	version='0.1.5.6',
	description='Solver for Toeplitz Inverse Covariance-based Clustering (TICC)',
	url='https://github.com/davidhallac/ticc',
	py_modules=['ticc']
	)
